<?php
if ( ! class_exists( 'IPTesti_Factory' )) {

    /**
     * Class for create share
     */
    class IPTesti_Factory
    {
        /**
         * Class construct
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get testimony list
         *
         * @return string
         */
        public function testimony( $atts, $widgetArgs = false )
        {
            if ( empty( $atts['style'] )) {
                return;
            }
            //
            //Get style
            $style_id = absint( $atts['style'] );
            if ( ! $style = get_post( $style_id )) {
                return;
            }
            $this->style         = $style;
            $this->style_setting = new IPTesti_Setting( $style_id, '__iptesti-style-setting' );
            $this->widgetArgs    = $widgetArgs;
            $this->args          = $atts;
            //
            //Get testimonies
            $this->testimonies   = $this->_get_testimonies( $atts );
            
            //
            //Schema
            $schema = false;
            if ( $widgetArgs )
            {
                $option = get_option( '__iptesti_schema_widget', 'false' );
                if ( $option == 'true' ) {
                    $schema = true;
                }
            } else 
            {
                $option = get_option( '__iptesti_schema_shortcode', 'false' );
                if ( $option == 'true' ) {
                    $schema = true;
                }
            }
            $this->schema = $schema;
            $this->product_name = $this->_get_product_name( $atts );
            
            //
            //Include editor testimony
            if ( $widgetArgs ) {
                $path = IPTESTI_PATH . 'app/views/public/testimony/widget.php';
                include( $path );
            } else {
                $path = IPTESTI_PATH . 'app/views/public/testimony/shortcode.php';
                include( $path );
            }
            return true;
        }
        
        /**
         * Get testimonies
         *
         * @return array
         */
        protected function _get_testimonies( $atts )
        {
            $args = array();
            //
            //Page
            $page = 1;
            if ( ! empty( $_GET['iptesti_page'] )) {
                $page = absint( $_GET['iptesti_page'] );
            }
            //
            //Order
            $orderby = 'testi_order';
            $order   = 'ASC';
            if ( ! empty( $atts['orderby'] )) {
                $orderby = strtolower( 'testi_' . $atts['orderby'] );
            }
            if ( ! empty( $atts['order'] )) {
                $order = strtoupper( $atts['order'] );
            }
            $args['orderby'] = $orderby;
            $args['order']   = $order;
            //
            //Limit
            $perpage = 0;
            if ( ! empty( $atts['limit'] )) {
                $limit = absint( $atts['limit'] );
                $args['limit']  = $limit;
                $args['offset'] = $limit * ($page-1);
                $perpage        = $limit;
            }
            //
            //Group
            if ( ! empty( $atts['group'] )) {
                $group_id = absint( $atts['group'] );
                if ( $group = get_post( $group_id )) {
                    $args['group'] = $group_id;
                }
            }
            $model   = new IPTesti_Model();
            $items   = $model->getTestimonies( $args );
            $total   = $this->found_rows();
            $perpage = $args['limit'];
            
            return array(
                'items'   => $items,
                'total'   => $total,
                'perpage' => $perpage,
                'page'    => $page
            );
        }
        
        /**
         * Get found rows
         *
         * @return int
         */
        public function found_rows()
        {
            global $wpdb;
            $count   = 0;
            $query   = "SELECT FOUND_ROWS()";
            $results = $wpdb->get_col( $query );
            if ( ! empty( $results )) {
                $count = array_shift( $results );
            }
            return $count;
        }
        
        /**
         * Get form testimony
         *
         * @param array $atts
         * @return string
         */
        public function form( $atts, $widgetArgs = false )
        {
            if ( empty( $atts['form'] )) {
                return '';
            }
            $style = 1;
            if ( ! empty( $atts['style'] )) {
                $style = absint( $atts['style'] );
            }
            $label = false;
            if ( ! empty( $atts['label'] )) {
                $label = true;
            }
            $display = 'block';
            if ( ! empty( $atts['display'] )) {
                $display = $atts['display'];
            }
            $form_id = absint( $atts['form'] );
            if ( ! $form = get_post( $form_id )) {
                return '';
            }
            $this->form_id = $form_id;
            $this->form    = $form;
            $this->style   = $style;
            $this->setting = new IPTesti_Setting( $form_id, '__iptesti-form-setting' );
            $this->widgetArgs = $widgetArgs;
            $this->useLabel   = $label;
            $this->display    = $display;
            
            //
            //Include editor testimony
            if ( $widgetArgs ) {
                $path = IPTESTI_PATH . 'app/views/public/form/widget.php';
                include( $path );
            } else {
                $path = IPTESTI_PATH . 'app/views/public/form/shortcode.php';
                include( $path );
            }
            return true;
        }
        
        /**
         * Get page content
         *
         * @return string $content
         * @return string
         */
        public function page( $content )
        {
            global $post;
            
            $testi = '';
            if ( $post && $post->post_type == 'iptesti-item' ) 
            {
                $model   = new IPTesti_Model();
                $post_id = $post->ID;
                if ( $testimony = $model->getTestimonyByPage( $post_id )) 
                {
                    $style_id = 1;
                    if ( ! empty( $_GET['style'] )) {
                        $style_id = absint( $_GET['style'] );
                    }
                    $this->style_setting = new IPTesti_Setting( $style_id, '__iptesti-style-setting' );
                    $this->testimony     = $testimony;
                    $this->in_single     = true;
            
                    //
                    //Schema
                    $schema = false;
                    $option = get_option( '__iptesti_schema_page', 'false' );
                    if ( $option == 'true' ) {
                        $schema = true;
                    }
                    $this->schema = $schema;
            
                    //
                    //Get content
                    ob_start();
                    $this->view( 'testimony/single' );
                    $testi = ob_get_contents();
                    ob_end_clean();
                }
            }
            $content .= $testi;
            return $content;
        }
        
        /**
         * Get public view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPTESTI_PATH . 'app/views/public/';
            $path .= strtolower( $filename ) . '.php'; 
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get image thumbnail
         *
         * @param int $attach_id
         * @return void
         */
        public function get_thumbnail( $attach_id, $config, $style )
        {
            $imgpath  = get_attached_file( $attach_id );
            $root     = dirname( $imgpath );
            $ext      = pathinfo(  $imgpath, PATHINFO_EXTENSION);
            $filename = basename( $imgpath, '.' . $ext );
            
            $height  = $style->getSetting( 'thumbnail_height', 78 );
            $width   = $style->getSetting( 'thumbnail_width', 78 );
            if ( $style->getSetting( 'thumbnail_crop', 'true' ) == 'true' ) {
                $crop = true;
            } else {
                $crop = false;
            }
            $newfilename = $filename . "_$height" . "x$width" . '_' . (int)$crop . ".$ext";
            $newfile     = $root . '/' . $newfilename;
            
            if ( ! file_exists( $newfile )) {
                $image = wp_get_image_editor( $imgpath );
                if ( ! is_wp_error( $image ) ) {
                    $image->resize( $height, $width, $crop );
                    $image->save( $newfile );
                }
            }
            $upload_dir = wp_upload_dir();
            $base_url   = $upload_dir['baseurl'];
            $imgmeta    = wp_get_attachment_metadata( $attach_id );
            $imgdir     = dirname( $imgmeta['file'] );
            $imgurl     = $base_url . '/' . $imgdir . '/' . $newfilename;
            
            return $imgurl;
        }
        
        /**
         * Get link view
         *
         * @param  object $item
         * @param  object $style
         * @return string
         */
        public function get_casestudy_link( $item, $style )
        {
            $home = get_home_url();
            $base = get_option( '__iptesti_slug', 'testimonials' );
            
            if ( get_option( 'permalink_structure' ) )  
            {
                $page = get_post( $item->testi_page );
                $link = $home . "/$base/" . $page->post_name . '?style=' . $style->ID;
            } else {
                $link = $home . '/?testimony_id=' . $item->testi_page . '&iptesti=1&style=' . $style->ID;
            }
            
            return $link;
        }
        
        /**
         * Fix youtube url
         *
         * @param  string $url
         * @return string
         */
        public function fix_youtube_url( $url )
        {
            if ( $url )
            {
                if ( strpos( $url, 'embed' ) === false ) {
                    if ( strpos( $url, 'watch' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['query'] )) {
                            parse_str( $parsed['query'], $args );
                            if ( ! empty( $args['v'] )) {
                                $id = $args['v'];
                            }
                        }
                        $url = 'http://youtube.com/embed/' . $id;
                    
                    } elseif ( strpos( $url, 'youtu.be' ) !== false ) {
                        $id     = '';
                        $parsed = parse_url( $url );
                        if ( ! empty( $parsed['path'] )) {
                            $id = trim( $parsed['path'], '/' );
                        }
                        $url = 'http://youtube.com/embed/' . $id;
                    
                    }
                }
                $url .= '?rel=0';
            }
            return $url;
        }
        
        /**
         * Get product name
         *
         * @param  array  $atts
         * @return string
         */
        protected function _get_product_name( $atts )
        {
            $title = get_option( '__iptesti_product_name' );
            $useGroup = get_option( '__iptesti_group_as_product', 'false' );
            if ( $useGroup == 'true' ) {
                if ( ! empty( $atts['group'] )) {
                    $group_id = absint( $atts['group'] );
                    if ( $group = get_post( $group_id )) {
                        $title = $group->post_title;
                    }
                    elseif ( ! empty( $atts['product'] ) ) {
                        $title = $atts['product'];
                    }
                }
            } 
            elseif ( ! empty( $atts['product'] ) ) {
                $title = $atts['product'];
            }
            return $title;
        }
    }
}