<?php
if ( ! class_exists( 'IPTesti_Widget_Form' )) {

    /**
     * Class for handling display widget
     */
    class IPTesti_Widget_Form extends WP_Widget
    {
        /**
         * Register widget with WordPress.
         */
        public function __construct() 
        {
            parent::__construct(
                'iptesti_testimony_form', // Base ID
                'Form Testimony', // Name
                array( 'description' => __( 'A Widget for display form testimony', 'wp_testimony_plus' ), )
            );
        }

        /**
         * Front-end display of widget.
         *
         * @see WP_Widget::widget()
         *
         * @param array $args     Widget arguments.
         * @param array $instance Saved values from database.
         */
        public function widget( $args, $instance ) 
        {
            $factory = new IPTesti_Factory();
            $factory->form( $instance, $args );
        }

        /**
         * Back-end widget form.
         *
         * @see WP_Widget::form()
         *
         * @param array $instance Previously saved values from database.
         */
        public function form( $instance ) 
        {
        ?>
            <p>
                <label for="<?php echo $this->get_field_name( 'form' ); ?>"><?php _e( 'Form:', 'wp_testimony_plus' ); ?></label> 
                <select id="<?php echo $this->get_field_id( 'form' ); ?>" name="<?php echo $this->get_field_name( 'form' ); ?>">
                    <?php
                    $form_id = absint( $instance['form'] );
                    $args = array(
                        'orderby'        => 'post_title',
                        'order'          => 'DESC', 
                        'post_type'      => 'iptesti-form',
                        'post_status'    => array('publish'),
                        'posts_per_page' => -1,
                        'paged'          => 1
                    );
                    $query = new WP_Query;
                    $forms = $query->query( $args );
                    foreach( $forms as $form ) 
                    {
                        $selected = '';
                        if ( $form_id == $form->ID ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $form->ID .  '">' . $form->post_title . '</option>';
                    }
                    ?>
                </select>
            </p>
            <p>
                <label for="<?php echo $this->get_field_name( 'display' ); ?>"><?php _e( 'Display:', 'wp_testimony_plus' ); ?></label> 
                <select id="<?php echo $this->get_field_id( 'display' ); ?>" name="<?php echo $this->get_field_name( 'display' ); ?>">
                    <?php
                    $display_id = $instance['display'];
                    $options    = array(
                        'inline'   => __( 'Inline', 'wp_testimony_plus' ),
                        'block'    => __( 'Block', 'wp_testimony_plus' )
                    );
                    foreach( $options as $key => $label ) 
                    {
                        $selected = '';
                        if ( $display_id == $key ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $key .  '">' . $label . '</option>';
                    }
                    ?>
                </select>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id( 'label' ); ?>">
                    <?php
                    $check = '';
                    if ( isset( $instance['label'] ) && $instance['label'] == 1 ) {
                        $check = ' checked="checked"';
                    }
                    ?>
                    <input id="<?php echo $this->get_field_id( 'label' ); ?>" type="checkbox" name="<?php echo $this->get_field_name( 'label' ); ?>"<?php echo $check; ?> value="1">
                    <?php _e( 'Use input label', 'wp_testimony_plus' ); ?>
                </label> 
            </p>
            <?php 
        }

        /**
         * Sanitize widget form values as they are saved.
         *
         * @see WP_Widget::update()
         *
         * @param array $new_instance Values just sent to be saved.
         * @param array $old_instance Previously saved values from database.
         *
         * @return array Updated safe values to be saved.
         */
        public function update( $new_instance, $old_instance ) 
        {
            $instance = array();
            if ( ! empty( $new_instance['form'] ) ) {
                $instance['form'] = absint( $new_instance['form'] ); 
            }
            if ( ! empty( $new_instance['display'] ) ) {
                $instance['display'] = apply_filters( 'pre_term_name', $new_instance['display'] ); 
            }
            if ( ! empty( $new_instance['style'] ) ) {
                $instance['style'] = absint( $new_instance['style'] ); 
            }
            if ( isset( $new_instance['label'] ) ) {
                $instance['label'] = 1; 
            }
            return $instance;
        }
    }

}
?>