/*
 *===========================================================
 * UI
 *===========================================================
 */
(function($)
{
    "use strict";
    
    //Inherit function
    function inherit( proto ) 
    {
        function F() {}
        F.prototype = proto
        return new F
    }

    /*
     *===========================================================
     * Ui prototype
     *===========================================================*/
    function ui_construct( options ){};
    
    ui_construct.prototype = 
    {
        
        vars:               {},
        class_prefix:       'ipbe-',
        class_main:         '-main',
        class_title:        '-title',
        class_content:      '-content',
        class_disabled:     'disabled',
        class_close:        'ui-close',
        label_close:        'x',
        image_base:         '',
        
        top_margin:         '80px',
        overlay_speed:      600,
        main_speed:         400,
        show_speed:         4000,
        
        show_after:         function(){},
        hide_after:         function(){},
        
        popup_body: function( class_root, content, title, close )
        {
            var body = $( '<div class="'+class_root+'"></div>' );
            var main = $( '<div class="'+class_root + this.class_main+'"></div>' );
            if ( title ) 
            {
                var _title = $( '<div class="'+class_root + this.class_title+'"></div>' )
                                .append( '<h3>'+title+'</h3>' );
                if ( close ) 
                {
                    var _close = $( '<a href="#">'+this.label_close+'</a>' );
                    this.popup_close( _close, class_root );
                    
                    _title.append( 
                        $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close ) 
                    );
                }
                main.append( _title );
            }
            if ( content ) {
                main.append( 
                    $( '<div class="'+class_root + this.class_content+'"></div>' ).append( content )
                );
            }
            body.append( main );
            return body;
        },
        popup_show: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );
            popup.show();
            main.css( 'margin-top', '-40%' )
                .animate({marginTop: this.top_margin}, this.main_speed, this.show_after);
        },
        popup_hide: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );
            
            popup.animate( {opacity: 0}, this.overlay_speed, function(){
                $(this).css( 'opacity', 1 )
                       .hide();
            });
            main.animate( {marginTop: '-60%'}, this.main_speed, this.hide_after);
        },
        popup_close: function( button, class_popup )
        {
            var ui = this;
            button.click( function(){
                var popup = $( '.'+class_popup );
                ui.popup_hide( popup );
                return false;
            });
        },
        is_load: function( selector )
        {
            if ( $( selector ).length > 0 ) {
                return true;
            }
            return false;
        },
        set_vars: function( options )
        {
            this.vars = $.extend(this.vars, options);
        },
        set_base_vars: function( options )
        {
            this.vars = $.extend(this, options);
        },
        go_to: function( selector )
        {
            var pos = $( selector ).position();
            $('html, body').animate({scrollTop: ( pos.top )}, 600);
            return false;
        }
    };
    
    /*
     * Modal Class
     **/
    function modal(){};
    modal.prototype = inherit( ui_construct.prototype );
    //Modal message
    modal.prototype.ajax = function( id, url )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var modal   = this.popup_body( c_root, '', false, false ).appendTo( $( 'body' ) );
        modal.addClass( class_type )
             .attr( 'id', id );
        
        this.popup_show( modal );
    };
    
    /*
     * Loader Class
     **/
    function loader(){};
    loader.prototype = inherit( ui_construct.prototype );
    //Properties
    loader.prototype.class_root     = 'ui-loader';
    loader.prototype.loader_file    = 'loading.gif';
    //Show loader
    loader.prototype.show = function()
    {
        var loader = this.create();
        this.popup_show( loader );
    };
    //Hide loader
    loader.prototype.hide = function()
    {
        var loader = this.create();
        this.popup_hide( loader );
    };
    //Create loader
    loader.prototype.create = function()
    {
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else 
        {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = this.popup_body( c_root, image, false, false ).appendTo( $( 'body' ) );
            loader.hide();
            
            return loader;
        }
    };
    
    
    /*
     * Inline loader Class
     **/
    function iloader(){};
    iloader.prototype = inherit( ui_construct.prototype );
    //Properties
    iloader.prototype.class_root   = 'ui-inline-loader';
    iloader.prototype.loader_file  = 'spin.gif';
    //Loader show
    iloader.prototype.show = function( button )
    {
        button.attr( 'disabled', 'disabled' );
        this.create( button ).show();
    };
    //Loader hide
    iloader.prototype.hide = function( button )
    {
        button.removeAttr( 'disabled' );
        this.create( button ).hide();
    };
    //Creating loader
    iloader.prototype.create = function( button )
    {
        var root   = button.parent();
        var lclass = this.class_prefix + this.class_root;
        if ( $( '.'+lclass, root ).length > 0 ) {
            var loader = $( '.'+lclass, root );
        } else {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = $( '<span class="'+lclass+'"></span>' )
                            .append( image )
                            .css( 'margin-left', '8px' );
        }
        button.after( loader );
        return loader;
    };
    
    
    /*
     * Confirm popup
     **/
    function confirm( options )
    {
        var defaults = {
            title:      'Confirmation',
            info:       '',
            yes_label:  'Yes',
            no_label:   'Cancel',
            yes_class:  'btn btn-danger',
            no_class:   'btn btn-success',
            action:     function( object ){}
        };
        this.vars = $.extend(defaults, options);
    };
    confirm.prototype = inherit( ui_construct.prototype );
    //Properties
    confirm.prototype.class_root = 'ui-confirm';
    //Confirm show
    confirm.prototype.show = function( object )
    {
        var confirm = this.create( object );
        this.popup_show( confirm );
    };
    //Confirm hide
    confirm.prototype.hide = function( object )
    {
        var confirm = this.create( object );
        this.popup_hide( confirm );
    };
    //Creating confirm
    confirm.prototype.create = function( object )
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            $( '.'+c_root ).remove();
        }
        //Create confirm
        var yesbtn = $( '<a href="#" class="ip-confirm-yes '+this.vars.yes_class+'">'+this.vars.yes_label+'</a>' );
        var nobtn  = $( '<a href="#" class="ip-confirm-no '+this.vars.no_class+'">'+this.vars.no_label+'</a>' );
        
        yesbtn.click( function(){
            ui.vars.action( object, ui );
            return false;
        });
        this.popup_close( nobtn, c_root );
        
        var content = $( '<div class="'+c_root+'-inner"></div>' )
            .append( '<p>'+this.vars.info+'</p>' )
            .append( 
                $( '<div class="'+c_root+'-actions"></div>' )
                    .append( yesbtn )
                    .append( nobtn )
            );
        
        var confirm = this.popup_body( c_root, content, this.vars.title, false ).appendTo( $( 'body' ) );
        confirm.hide();
        
        return confirm;
    };
    
    
    /*
     * Alert popup
     **/
    function alert( options )
    {
        var defaults = {
            message:        '',
            label_button:   'Ok',
            class_root:     '',
            class_button:   'btn btn-danger',
            after:          function(){}
        };
        this.vars = $.extend(defaults, options);
    };
    alert.prototype = inherit( ui_construct.prototype );
    //Properties
    alert.prototype.class_root = 'ui-alert';
    //Alert show
    alert.prototype.show = function( message )
    {
        this.vars.message = message;
        var alert = this.create();
        this.popup_show( alert );
    };
    //Alert hide
    alert.prototype.hide = function()
    {
        var alert = this.create();
        this.hide_after = this.vars.after;
        this.popup_hide( alert );
    };
    //Creating alert
    alert.prototype.create = function()
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else 
        {
            var button = $( '<a href="#" class="'+this.vars.class_button+'">'+this.vars.label_button+'</a>' );
            this.popup_close( button, c_root );
            
            var c_info  = c_root + '-inner';
            if ( this.vars.class_root != '' ) {
                c_info += ' ' + this.vars.class_root;
            }
            var content = $( '<div class="'+c_info+'"></div>' )
                .append( '<p>'+this.vars.message+'</p>' )
                .append( 
                    $( '<div class="'+c_root+'-actions"></div>' )
                        .append( button )
                );
            
            var popup  = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
            popup.hide();
            
            return popup;
        }
    };
    
    
    /*
     * Message
     **/
    function message(){};
    message.prototype = inherit( ui_construct.prototype );
    //Properties
    message.prototype.class_modal = 'ui-modal-message';
    message.prototype.class_block = 'ui-message';
    //Modal message
    message.prototype.modal = function( message, class_type )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var content = '<p>'+message+'</p>';
        var msg     = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
        msg.addClass( class_type )
           .show()
           .animate({top: "0"}, ui.overlay_speed, function(){
                var object = $( this );
                setTimeout( function(){
                    object.animate({top: '-100px'}, ui.overlay_speed, function(){
                        object.remove();
                    });
                }, ui.show_speed);
            });
    };
    //Bloack message
    message.prototype.block = function( message, class_type, block, close )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_block;
        var parent  = block.parent();
        
        $( '.'+c_root, parent ).remove();
        
        var msg = $( '<div></div>' );
        msg.addClass( c_root )
           .addClass( class_type )
           .append( '<p>'+message+'</p>' );
        
        if ( close ) 
        {
            var _close = $( '<a href="#">'+this.close_label+'</a>' );
            _close.click( function()
            {
                var _msg = $(this).parents( '.'+c_root );
                _msg.animate({opacity: "0"}, ui.overlay_speed, function(){
                    _msg.remove();
                });
                return false;
            });
            msg.append( 
                $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close ) 
            );
        }
        msg.css( 'opacity', '0' );
        parent.prepend( msg );
        msg.animate({opacity: "1"}, ui.overlay_speed);
    };
    
    //Set global variable
    if ( typeof window.ip_ui == 'undefined' )
    {
        window.ip_ui = 
        {
            base: {
                construct:  ui_construct,
                loader:     loader,
                iloader:    iloader,
                confirm:    confirm,
                message:    message,
                alert:      alert,
                modal:      modal
                
            },
            init: function()
            {
                this.loader  = new this.base.loader(),
                this.iloader = new this.base.iloader(),
                this.confirm = new this.base.confirm(),
                this.message = new this.base.message(),
                this.alert   = new this.base.alert(),
                this.modal   = new this.base.modal()
            }
        };
    }
    
})(jQuery);
/*
 *===========================================================
 * Modal
 *===========================================================*/
(function($)
{
    "use strict";
    
    /**
     * Modal link
     */
    $.fn.ip_modal = function()
    {
        $(this).each( function()
        {
            var link  = $(this);
            var href  = link.attr( 'href' );
            var popup = $( href );
            
            ip_ui.modal.top_margin = '10px';
            
            //Link close 
            var close_class = ip_ui.modal.class_prefix + ip_ui.modal.class_close;
            $( '.'+close_class, popup ).click( function()
            {
                ip_ui.modal.popup_hide( popup );
                return false;
            });
            
            //Link open
            link.click( function()
            {
                ip_ui.modal.popup_show( popup );
                return false;
            });
        });
    };
    
    /**
     * Modal ajax handler
     */
    $.fn.ip_modal_ajax = function( options )
    {
        var defaults  = {
            modalSelector:  '.ipbe-ui-modal',
            mainSelector:   '.ipbe-ui-modal-content',
            loaderUrl:      '',
            getAjaxUrl:     function( button ){},
            getAjaxData:    function( button ){
                return '';
            },
            ajaxSuccess:     function( result, button, popup ){},
            afterClosePopup: function( button, popup ){}
        };
        var options = $.extend( defaults, options );
        
        var popup  = $( options.modalSelector );
        var main   = $( options.mainSelector, popup );
        
        //Button close 
        var close_class = ip_ui.modal.class_prefix + ip_ui.modal.class_close;
        $( '.'+close_class, popup ).click( function()
        {
            ip_ui.modal.popup_hide( popup );
            options.afterClosePopup( popup );
            return false;
        });
        
        $(this).each( function()
        {
            var button = $(this);
            //Button open
            button.click( function()
            {
                //Insert Loader
                main.html( '<img class="loader" src="' + options.loaderUrl + '" alt="Loading...">' );
                
                var url  = options.getAjaxUrl( button );
                var data = options.getAjaxData( button );
                $.ajax({
                    url: url,
                    type: "POST",
                    dataType: "html",
                    data: data,
                    success: function (result) 
                    {
                        options.ajaxSuccess( result, button, popup, main );
                    }
                });
                
                ip_ui.modal.popup_show( popup );
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * On Off Button
 *===========================================================*/
(function($)
{
    "use strict";
    
    /**
     * On Off button
     */
    $.fn.ipbe_btn_onoff = function( options ) 
    {
        var defaults  = {
            func_select: function( button ){},
        };
        var options = $.extend( defaults, options );
        
        $(this).each( function(){
        
            var cont = $(this);
            $( '.ipbe-btn', cont ).click( function()
            {
                var value = $(this).data( 'value' );
                if ( ! $(this).hasClass( 'active' ) ) {
                    $( 'button', cont ).removeClass( 'active' );
                    $( 'button', cont ).removeClass( 'ipbe-btn-success' );
                    $( 'button', cont ).removeClass( 'ipbe-btn-danger' );
                    if ( value == true ) {
                        $(this).addClass( 'ipbe-btn-success' );
                    } else {
                        $(this).addClass( 'ipbe-btn-danger' );
                    }
                    $(this).addClass( 'active' );
                }
                $( '.ipbe-onoff-value', cont ).val(value);
                
                var field = $(this).parents( '.ipbe-field-row' );
                if ( field.hasClass( 'ipbe-toggle' )) {
                    
                    if ( value == 'false' || value == false ) {
                        $( '.ipbe-toggle-option', field ).hide();
                    } else {
                        $( '.ipbe-toggle-option', field ).show();
                    }
                }
                options.func_select( cont );
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Admin Global
 *===========================================================
 */
(function($)
{
    ip_ui.init();
    
    $(document).ready(function() 
    {
        //
        //Button On Off
        //
        if ( $( '.ipbe-btn-onoff' ).length > 0 ) {
            $( '.ipbe-btn-onoff' ).ipbe_btn_onoff();
        }
        
        $( '.iptesti-ui-close-link' ).click( function()
        {
            var popup = $(this).parents( '.ipbe-ui-modal' );
            ip_ui.modal.popup_hide( popup );
        });
        
        //Insert testimony
        $( '#iptesti_scadd_testimony' ).click( function()
        {
            var btn = $(this);
            var aed = tinyMCE.activeEditor;
            if ( aed ) 
            {
                var attr  = 'group="' + $( '#iptesti-isc-testimony-group' ).val() + '"';
                attr += ' orderby="' + $( '#iptesti-isc-testimony-orderby' ).val() + '"';
                attr += ' order="' + $( '#iptesti-isc-testimony-order' ).val() + '"';
                attr += ' limit="' + $( '#iptesti-isc-testimony-limit' ).val() + '"';
                attr += ' style="' + $( '#iptesti-isc-testimony-style' ).val() + '"';
                attr += ' product="' + $( '#iptesti-isc-testimony-product' ).val() + '"';
                var content = '[testimonials ' + attr + '][/testimonials]';
                aed.selection.setContent( content );
                //
                //Reset form
                var forms = btn.parents( 'form' );
                forms[0].reset();
                
            }
            
            var popup = btn.parents( '.ipbe-ui-modal' );
            ip_ui.modal.popup_hide( popup );
            return false;
        });
        
        //Insert form
        $( '#iptesti_scadd_form' ).click( function()
        {
            var btn = $(this);
            var aed = tinyMCE.activeEditor;
            if ( aed ) 
            {
                var attr  = 'form="' + $( '#iptesti-isc-form' ).val() + '"';
                attr += ' display="' + $( '#iptesti-isc-form-display' ).val() + '"';
                attr += ' label="' + $( '#iptesti-isc-form-label' ).val() + '"';
                var content = '[testimony_form ' + attr + '][/testimony_form]';
                aed.selection.setContent( content );
                //
                //Reset form
                var forms = btn.parents( 'form' );
                forms[0].reset();
                
            }
            
            var popup = btn.parents( '.ipbe-ui-modal' );
            ip_ui.modal.popup_hide( popup );
            return false;
        });
        
    });
})(jQuery);