<?php
/*
Plugin Name: WP Testimony Plus - Lite
Plugin URI: 
Description: Plugin that is used to manage user testimony in your website
Version: 1.0
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPTESTI_TITLE', 'WP Testimony Plus - Lite' );
define( 'IPTESTI_FILE', __FILE__ );
define( 'IPTESTI_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPTESTI_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( IPTESTI_PATH . "app/config.php" );
require_once( IPTESTI_PATH . "app/setting.php" );
require_once( IPTESTI_PATH . "app/db.php" );
require_once( IPTESTI_PATH . "app/ajax.php" );
require_once( IPTESTI_PATH . "app/admin.php" );
require_once( IPTESTI_PATH . "app/model.php" );
require_once( IPTESTI_PATH . "app/model_form.php" );
require_once( IPTESTI_PATH . "app/model_style.php" );
require_once( IPTESTI_PATH . "app/shortcode.php" );
require_once( IPTESTI_PATH . "app/factory.php" );

/**
 * Main class
 */
if ( ! class_exists( 'IPTesti' )) {

    class IPTesti
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( IPTESTI_TITLE );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );
            
            //Plugin init
            add_action( 'init', array( __CLASS__, 'i18n' ) );
            
            //Plugin admin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            //Register Widget
            add_action( 'widgets_init', array( __CLASS__, 'widget_init' ));
            
            //
            //Editor button & Shortcode
            
            //Add Editor Button
            add_action( 'admin_init', array( __CLASS__, 'add_editor_button' ) );
            
            //Add Editor Dialog
            add_action( 'tiny_mce_preload_dialogs', array( __CLASS__, 'create_editor' ) );
            add_action( 'after_wp_tiny_mce', array( __CLASS__, 'create_editor' ) );
            
            //Add Shortcode
            add_shortcode( 'testimonials', array( __CLASS__, 'shortcode_testimony' ) );
            add_shortcode( 'testimony_form', array( __CLASS__, 'shortcode_form' ) );
            
            //
            //Request Handler
            //
            
            //Rewrite Handler
            add_action( 'init', array( __CLASS__, 'rewrite_flush' ) );
            add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );
            
            //Render page
            add_filter( 'the_content', array( __CLASS__, 'page' ) );
            
            
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'style_admin_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_iptesti', array( __CLASS__, 'style_admin' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptesti-group', array( __CLASS__, 'style_admin' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptesti-style', array( __CLASS__, 'style_admin' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptesti-form', array( __CLASS__, 'style_admin' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptesti-setting', array( __CLASS__, 'style_admin' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_iptesti', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptesti-group', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptesti-style', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptesti-form', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptesti-setting', array( __CLASS__, 'script_admin' ), 1000 );
            add_action( 'admin_print_scripts', array( __CLASS__, 'global_script_admin' ), 1100 );
            
            
            //Front style & script
            add_action('wp_head', array( __CLASS__, 'public_style' ) );
            
            if ( ! is_admin() ) {
                add_action('wp_enqueue_scripts', array( __CLASS__, 'public_script' ), 10 );
            }
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Install DB
            $db = new IPTesti_Db();
            $db->install();
        }
        
        /**
         * Update Db
         *
         * @return void
         */
        public static function updateDb()
        {
            $db = new IPTesti_Db();
            $db->update();
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                IPTESTI_TITLE, 
                IPTESTI_TITLE, 
                'iptesti_manage', 
                'iptesti',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'iptesti',
                __( 'Testimonies', 'wp_testimony_plus' ), 
                __( 'Testimonies', 'wp_testimony_plus' ), 
                'iptesti_manage', 
                'iptesti',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'iptesti',
                __( 'Groups', 'wp_testimony_plus' ), 
                __( 'Groups', 'wp_testimony_plus' ), 
                'iptesti_manage', 
                'iptesti-group',
                array( __CLASS__, 'admin_group' )
            );
            add_submenu_page( 
                'iptesti',
                __( 'Styles', 'wp_testimony_plus' ), 
                __( 'Styles', 'wp_testimony_plus' ), 
                'iptesti_manage', 
                'iptesti-style',
                array( __CLASS__, 'admin_style' )
            );
            add_submenu_page( 
                'iptesti',
                __( 'Forms', 'wp_testimony_plus' ), 
                __( 'Forms', 'wp_testimony_plus' ), 
                'iptesti_manage', 
                'iptesti-form',
                array( __CLASS__, 'admin_form' )
            );
            add_submenu_page( 
                'iptesti',
                __( 'Settings', 'wp_testimony_plus' ), 
                __( 'Settings', 'wp_testimony_plus' ), 
                'iptesti_manage', 
                'iptesti-setting',
                array( __CLASS__, 'admin_setting' )
            );
        }
        
        /**
         * Handle internationalization
         *
         * @return void
         */
        public static function i18n()
        {
            load_plugin_textdomain( 'wp_testimony_plus', false, basename( IPTESTI_PATH ) . '/languages/' );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'iptesti_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPTesti_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPTesti_Admin();
            $display->index();
        }
        
        /**
         * Content for administrator group
         *
         * @return void
         */
        public static function admin_group()
        {
            $display = new IPTesti_Admin();
            $display->group();
        }
        
        /**
         * Content for administrator styles
         *
         * @return void
         */
        public static function admin_style()
        {
            $display = new IPTesti_Admin();
            $display->style();
        }
        
        /**
         * Content for administrator forms
         *
         * @return void
         */
        public static function admin_form()
        {
            $display = new IPTesti_Admin();
            $display->form();
        }
        
        /**
         * Content for administrator settings
         *
         * @return void
         */
        public static function admin_setting()
        {
            $display = new IPTesti_Admin();
            $display->setting();
        }
        
        /**
         * Share factory
         *
         * @return void
         */
        public static function factory()
        {
            global $iptesti;
            
            if ( ! $iptesti ) {
                $iptesti = new IPTesti_Factory();
            }
            $iptesti->render();
        }
        
        /**
         * Widget innit
         */
        public function widget_init() 
        {
            require_once( IPTESTI_PATH . "app/widget_testimony.php" );
            register_widget( 'IPTesti_Widget_Testimony' );
            
            require_once( IPTESTI_PATH . "app/widget_form.php" );
            register_widget( 'IPTesti_Widget_Form' );
        }
        
        /**
         * Main method for parse testimony shortcode
         *
         * @param  array  $atts
         * @param  string $content
         * @return string
         */
        public static function shortcode_testimony( $atts, $content = '')
        {
            $factory = new IPTesti_Shortcode();
            return $factory->testimony( $atts, $content );
        }
        
        /**
         * Main method for parse testimony form shortcode
         *
         * @param  array  $atts
         * @param  string $content
         * @return string
         */
        public static function shortcode_form( $atts, $content = '')
        {
            $factory = new IPTesti_Shortcode();
            return $factory->form( $atts, $content );
        }
         
        /**
         * Hook function for add button to editor
         *
         * @return void
         */
        public static function add_editor_button() 
        {
            if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) {
                return;
            }
            if ( get_user_option('rich_editing') == 'true') {
                add_filter( 'mce_external_plugins', array( __CLASS__, 'add_tinymce_plugin' ));
                add_filter( 'mce_buttons', array( __CLASS__, 'register_tinymce_button' ));
            }
        }

        /**
         * Register button to TinyMce system
         *
         * @param  array $button
         * @return void
         */
        public static function register_tinymce_button( $buttons ) 
        {
           array_push($buttons, "|", "iptestisc");
           array_push($buttons, "|", "iptestiformsc");
           return $buttons;
        }

        /**
         * Register TinyMce plugin
         *
         * @param  array $plugin_array
         * @return void
         */
        public static function add_tinymce_plugin( $plugin_array ) 
        {
           $plugin_array['iptestisc'] = plugin_dir_url( __FILE__ ) . 'js/editor_testimony.js';
           $plugin_array['iptestiformsc'] = plugin_dir_url( __FILE__ ) . 'js/editor_form.js';
           return $plugin_array;
        }
        
        /**
         * Content editor dialog
         *
         * @return void
         */
        public static function create_editor()
        {
            $display = new IPTesti_Shortcode();
            $display->editor();
        }
        
        /**
         * Init request
         *
         * @return void
         */
        public static function init( $query )
        {
            $q = $query->query;
            if ( isset( $q['iptesti'] ) && isset( $q['testimony_slug'] )) {
                $query->query_vars['post_type'] = 'iptesti-item';
                $query->query_vars['name']      = $q['testimony_slug'];
                $query->query_vars['pagename']  = $q['testimony_slug'];
                $query->query['pagename']       = $q['testimony_slug'];
            
            } elseif( isset( $q['testimony_id'] )) {
                $query->query_vars['post_type'] = 'iptesti-item';
                $query->query_vars['p']         = absint( $q['testimony_id'] );
            }
        }
        
        /**
         * Init rewrite rule
         *
         * @return void
         */
        public static function rewriteInit()
        {
            $base = get_option( '__iptesti_slug', 'testimonial' );
            add_rewrite_rule(
                $base . '/([^/]+)/?$',
                'index.php?iptesti=1&testimony_slug=$matches[1]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?iptesti=1&testimony_slug=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?iptesti=1&testimony_slug=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/page/?([0-9]{1,})/?$',
                'index.php?iptesti=1&testimony_slug=$matches[1]&paged=$matches[2]',
                'top'
            );
            add_rewrite_tag( '%testimony_slug%', '([a-zA-Z0-9\_])');
            add_rewrite_tag( '%testimony_id%', '([0-9])');
            add_rewrite_tag( '%iptesti%', '([1])');
        }
        
        /**
         * Flush rewrite rule
         *
         * @return void
         */
        public static function rewrite_flush()
        {
            $base = get_option( '__iptesti_slug', 'testimonial' );
            $old  = get_option( '__iptesti_slug_old', 'testimonial' );
            
            self::rewriteInit();
            
            if ( $base != $old ) {
                flush_rewrite_rules();
                update_option( '__iptesti_slug_old', $base );
            }
        }
        
        /**
         * Page factory
         *
         * @return void
         */
        public static function page( $content )
        {
            //Factory
            $factory = new IPTesti_Factory();
            return $factory->page( $content );
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function style_admin()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('iptesti-admin-style');
            wp_register_style('iptesti-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('iptesti-admin-style');
            
            wp_deregister_style('iptesti-public-style');
            wp_register_style('iptesti-public-style', plugin_dir_url( __FILE__ ) . 'css/public.css', false, null);
            wp_enqueue_style('iptesti-public-style');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function style_admin_global()
        {
            wp_deregister_style('iptesti-admin-style-global');
            wp_register_style('iptesti-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('iptesti-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function script_admin($hook)
        {
        ?>
        <script type="text/javascript">
            var iptesti_img_url  = '<?php echo IPTESTI_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo IPTESTI_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp_testimony_plus' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp_testimony_plus' ); ?>'
                },
                iptesti_favicon_base = '<?php echo IPTESTI_BASE_URL . 'img/favicon/'; ?>';
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('iptesti-admin-script');
            wp_enqueue_script(
                'iptesti-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public static function global_script_admin($hook)
        {
            wp_deregister_script('iptesti-admin-global-script');
            wp_enqueue_script(
                'iptesti-admin-global-script',
                plugin_dir_url( __FILE__ ) . 'js/admin-global.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
        ?>
            <script type="text/javascript">
                var iptesti_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
                var iptesti_message = 
                {
                    input_error_name: '<?php _e( 'You must enter your name.', 'wp_testimony_plus' ); ?>',
                    input_error_email: '<?php _e( 'You must enter your email address.', 'wp_testimony_plus' ); ?>',
                    input_error_email_format: '<?php _e( 'Your email address is wrong format.', 'wp_testimony_plus' ); ?>',
                    input_error_content: '<?php _e( 'You must enter your comment.', 'wp_testimony_plus' ); ?>',
                };
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('iptesti-public-script');
            wp_enqueue_script(
                'iptesti-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPTesti::setup();
?>