<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPTesti_Ajax' )) {

    class IPTesti_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'iptesti_submit_testimony'  => 'submit_testimony',
            'iptesti_testimony_update'  => 'testimony_update',
            'iptesti_testimony_delete'  => 'testimony_delete',
            'iptesti_group_update'      => 'group_update',
            'iptesti_group_delete'      => 'group_delete',
            'iptesti_style_update'      => 'style_update',
            'iptesti_style_delete'      => 'style_delete',
            'iptesti_form_update'       => 'form_update',
            'iptesti_form_delete'       => 'form_delete',
            'iptesti_setting'           => 'setting',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['iptesti'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Submit testimony
         *
         * @return void
         */
        public function submit_testimony()
        {
            $form = false;
            if ( ! empty( $_POST['form_id'] )) {
                $form_id = absint( $_POST['form_id'] );
                $form    = get_post( $form_id );
            }
            if ( ! $form ) {
                echo json_encode( array(
                    'status'    => '-1',
                    'message'   => __( 'Error System', 'wp_testimony_plus' )
                ));
                die();
            }
            $setting = new IPTesti_Setting( $form->ID, '__iptesti-form-setting' );
            
            $testimonyId = $this->_add_testimony();
            if ( $testimonyId ) {
                $message = $setting->getSetting( 'message_thank', 'Success' );
                $status  = 1;
                //
                //Send email
                $sendto     = $setting->getSetting( 'admin_email' );
                $send_admin = $setting->getSetting( 'send_email' );
                $subject    = __( 'New Testimony', 'wp_testimony_plus' );
                $body       = 
                'On ' . date( 'd F Y, h:i:s' ) . ', has received a new testimony with the following data:
                Name: ' . $_POST['name'] . '
                Email: ' . $_POST['email'] . '
                Comment: ' . $_POST['comment'] . '
                Administrator
                ';
                
                add_filter( 'wp_mail_content_type', 'iptesti_set_html_content_type' );

                if ( ! empty( $sendto )) {
                    @wp_mail( $sendto, $subject, $body );
                }
                if ( ! empty( $send_admin )) {
                    $admin_email = get_option( 'admin_email' );
                    @wp_mail( $admin_email, $subject, $body );
                }
                remove_filter( 'wp_mail_content_type', 'iptesti_set_html_content_type' );
            }
            else {
                $message = $setting->getSetting( 'message_error', 'Error' );
                $status  = -1;
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $message
            ));
            die();
        }
        
        /**
         * Update testimony
         *
         * @return void
         */
        public function testimony_update()
        {
            $model    = new IPTesti_Model();
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['testimony_id'] )) {
                $testimonyId = absint( $_POST['testimony_id'] );
                if ( $testimony = $model->getTestimony( $testimonyId ) ) {
                    $this->_update_testimony( $testimony );
                } else {
                    $testimonyId = 0;
                }
            } else {
                $testimonyId = $this->_add_testimony();
            }
            if ( $testimonyId ) {
                $error = false;
            }
            if ( $error ) {
                $status = 0;
                $testimonyId = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a testimony.', 'wp_testimony_plus' );
                } else {
                    $message = __( 'Failed to save testimony.', 'wp_testimony_plus' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a testimony.', 'wp_testimony_plus' );
                    $redirect = admin_url() . 'admin.php?page=iptesti&create=1';
                } else {
                    $message = __( 'Testimony successfully saved.', 'wp_testimony_plus' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'testimonyid'  => $testimonyId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new testimony
         *
         * @return int
         */
        protected function _add_testimony()
        {
            global $user_ID;
            
            $model = new IPTesti_Model();
            //
            //Name
            if ( ! empty( $_POST['name'] )) {
                $name = apply_filters( 'single_post_title', $_POST['name'] );
            } else {
                $name = 'Someone';
            }
            $slug = $model->getTestimonySlug( $name );
            
            $data = array(
                'testi_group_id'         => 0,
                'testi_created'          => date( 'c' ),
                'testi_name'             => $name,
                'testi_slug'             => $slug,
                'testi_title'            => '',
                'testi_content'          => '',
                'testi_info'             => '',
                'testi_url'              => '',
                'testi_info_url'         => '',
                'testi_info_url_target'  => 0,
                'testi_email'            => '',
                'testi_thumbnail'        => '',
                'testi_page'             => 0,
                'testi_rating'           => 0,
                'testi_status'           => 1,
                'testi_order'            => 0,
            );
            //
            //URL
            if ( isset( $_POST['url'] )) {
                $data['testi_url'] = apply_filters( 'pre_link_url', $_POST['url'] );
            }
            //
            //Info
            if ( isset( $_POST['info'] )) {
                $data['testi_info'] = apply_filters( 'single_post_title', $_POST['info'] );
            }
            if ( isset( $_POST['info_url'] )) {
                $data['testi_info_url'] = apply_filters( 'pre_link_url', $_POST['info_url'] );
            }
            if ( isset( $_POST['info_url_target'] ) && $_POST['info_url_target'] == 'true' ) {
                $data['testi_info_url_target'] = 1;
            }
            //
            //Email
            if ( isset( $_POST['email'] )) {
                $data['testi_email'] = sanitize_email( $_POST['email'] );
            }
            //
            //title
            if ( isset( $_POST['title'] )) {
                $data['testi_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            //
            //content
            if ( isset( $_POST['content'] )) {
                $data['testi_content'] = $_POST['content'];
            }
            //
            //Rating
            if ( isset( $_POST['rating'] )) {
                $data['testi_rating'] = absint( $_POST['rating'] );
            }
            //
            //Order
            if ( isset( $_POST['order'] )) {
                $data['testi_order'] = absint( $_POST['order'] );
            }
            //
            //Group
            if ( isset( $_POST['group'] )) {
                $data['testi_group_id'] = absint( $_POST['group'] );
            }
            
            //
            //Thumbnail
            $settings = array();
            //
            //Activate
            if ( isset( $_POST['thumbnail_type'] )) {
                $settings['thumbnail_type'] = apply_filters( 'pre_term_name', $_POST['thumbnail_type'] );
            }
            //
            //Thumbnail
            if ( isset( $_POST['thumbnail'] )) {
                $settings['thumbnail'] = absint( $_POST['thumbnail'] );
            }
            //
            //Thumbnail url
            if ( isset( $_POST['thumbnail_url'] )) {
                $settings['thumbnail_url'] = apply_filters( 'pre_link_url', $_POST['thumbnail_url'] );
            }
            //
            //Thumbnail url target
            if ( isset( $_POST['thumbnail_url_target'] )) {
                $settings['thumbnail_url_target'] = apply_filters( 'pre_term_name', $_POST['thumbnail_url_target'] );
            }
            //
            //Thumbnail preview
            if ( isset( $_POST['thumbnail_preview'] )) {
                $settings['thumbnail_preview'] = absint( $_POST['thumbnail_preview'] );
            }
            //
            //Thumbnail video url
            if ( isset( $_POST['thumbnail_video_url'] )) {
                $settings['thumbnail_video_url'] = apply_filters( 'pre_link_url', $_POST['thumbnail_video_url'] );
            }
            //
            //Thumbnail video target
            if ( isset( $_POST['thumbnail_video_target'] )) {
                $settings['thumbnail_video_target'] = apply_filters( 'pre_term_name', $_POST['thumbnail_video_target'] );
            }
            $data['testi_thumbnail'] = maybe_serialize( $settings );
            
            //
            //Activate
            if ( ! empty( $_POST['page_activate'] ) && $_POST['page_activate'] == 'true' ) 
            {
                $page_id = $this->_add_page( $name );
                $data['testi_page'] = $page_id;
            }
            
            $result = $model->insertTestimony( $data );
            return $result;
        }
        
        /**
         * Update testimony
         *
         * @param  object $testimony
         * @return boolean
         */
        protected function _update_testimony( $testimony )
        {
            $result = 0;
            $data   = array();
            if ( ! empty( $_POST['name'] ) && $_POST['name'] != $testimony->testi_name ) {
                $data['testi_name'] = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( isset( $_POST['info'] ) && $_POST['info'] != $testimony->testi_info ) {
                $data['testi_info'] = apply_filters( 'single_post_title', $_POST['info'] );
            }
            if ( isset( $_POST['email'] ) && $_POST['email'] != $testimony->testi_email ) {
                $data['testi_email'] = sanitize_email( $_POST['email'] );
            }
            if ( isset( $_POST['url'] )) {
                $data['testi_url'] = apply_filters( 'pre_link_url', $_POST['url'] );
            }
            if ( isset( $_POST['info_url'] ) && $_POST['info_url'] != $testimony->testi_info_url ) {
                $data['testi_info_url'] = apply_filters( 'pre_link_url', $_POST['info_url'] );
            }
            if ( isset( $_POST['info_url'] ) && $_POST['info_url'] != $testimony->testi_info_url ) {
                $data['testi_info_url'] = apply_filters( 'pre_link_url', $_POST['info_url'] );
            }
            if ( isset( $_POST['info_url_target'] )) {
                if ( $_POST['info_url_target'] == 'true' ) {
                    $data['testi_info_url_target'] = 1;
                } else {
                    $data['testi_info_url_target'] = 0;
                }
            }
            
            if ( isset( $_POST['rating'] ) && $_POST['rating'] != $testimony->testi_rating ) {
                $data['testi_rating'] = apply_filters( 'single_post_title', $_POST['rating'] );
            }
            if ( isset( $_POST['group'] ) && $_POST['group'] != $testimony->testi_group_id ) {
                $data['testi_group_id'] = absint( $_POST['group'] );
            }
            
            if ( isset( $_POST['title'] ) && $_POST['title'] != $testimony->testi_title ) {
                $data['testi_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( isset( $_POST['content'] ) && $_POST['content'] != $testimony->testi_content ) {
                $data['testi_content'] = $_POST['content'];
            }
            if ( isset( $_POST['order'] ) && $_POST['order'] != $testimony->testi_order ) {
                $data['testi_order'] = absint( $_POST['order'] );
            }
            
            //
            //Thumbnail
            $settings = array();
            //
            //Activate
            if ( isset( $_POST['thumbnail_type'] )) {
                $settings['thumbnail_type'] = apply_filters( 'pre_term_name', $_POST['thumbnail_type'] );
            }
            //
            //Thumbnail
            if ( isset( $_POST['thumbnail'] )) {
                $settings['thumbnail'] = absint( $_POST['thumbnail'] );
            }
            //
            //Thumbnail url
            if ( isset( $_POST['thumbnail_url'] )) {
                $settings['thumbnail_url'] = apply_filters( 'pre_link_url', $_POST['thumbnail_url'] );
            }
            //
            //Thumbnail url target
            if ( isset( $_POST['thumbnail_url_target'] )) {
                $settings['thumbnail_url_target'] = apply_filters( 'pre_term_name', $_POST['thumbnail_url_target'] );
            }
            //
            //Thumbnail preview
            if ( isset( $_POST['thumbnail_preview'] )) {
                $settings['thumbnail_preview'] = absint( $_POST['thumbnail_preview'] );
            }
            //
            //Thumbnail video url
            if ( isset( $_POST['thumbnail_video_url'] )) {
                $settings['thumbnail_video_url'] = apply_filters( 'pre_link_url', $_POST['thumbnail_video_url'] );
            }
            //
            //Thumbnail video target
            if ( isset( $_POST['thumbnail_video_target'] )) {
                $settings['thumbnail_video_target'] = apply_filters( 'pre_term_name', $_POST['thumbnail_video_target'] );
            }
            if ( ! empty( $settings )) {
                $data['testi_thumbnail'] = maybe_serialize( $settings );
            }
            
            //
            //Single page
            if ( ! empty( $_POST['page_activate'] ) && $_POST['page_activate'] == 'true' ) {
                if ( ! empty( $testimony->testi_page )) {
                    $this->_update_page( $testimony->testi_page );
                } else {
                    $page_id = $this->_add_page( $_POST['name'] );
                    $data['testi_page'] = $page_id;
                }
            } else {
                $data['testi_page'] = 0;
                if ( ! empty( $testimony->testi_page )) {
                    wp_delete_post( $testimony->testi_page, true );
                }
            }
            
            if ( ! empty( $data )) {
                $data['testi_id'] = $testimony->testi_id;
                $model  = new IPTesti_Model();
                $result = $model->updateTestimony( $testimony->testi_id, $data );
            }
            return $result;
        }
        
        /**
         * Add case study page
         *
         * @return int
         */
        protected function _add_page( $name )
        {
            global $user_ID;
            
            //
            //content
            $content = '';
            if ( isset( $_POST['page_content'] )) {
                $content = $_POST['page_content'];
            }
            $status   = 'publish';
            $dataPost = array(
                'post_status'  => 'publish', 
                'post_type'    => 'iptesti-item', 
                'post_author'  => $user_ID,
                'post_title'   => $name,
                'post_content' => $content
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update case study page
         *
         * @param  object $page_id
         * @return boolean
         */
        protected function _update_page( $page_id )
        {
            if ( ! $page = get_post( $page_id )) {
                return false;
            }
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['page_content'] ) && $_POST['page_content'] != $page->post_content ) {
                $dataPost['post_content'] = $_POST['page_content'];
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $page->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete testimony
         *
         * @return void
         */
        public function testimony_delete()
        {
            $item  = false;
            $model = new IPTesti_Model();
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = $model->getTestimony( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_testimony_plus' )
                ) );
                die();
            }
            $model  = new IPTesti_Model();
            $result = $model->deleteTestimony( $item->testi_id );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the testimony', 'wp_testimony_plus' ),
                    'redirect' => admin_url() . 'admin.php?page=iptesti&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the testimony', 'wp_testimony_plus' )
                ) );
            }
            die();
        }
        
        /**
         * Update
         *
         * @return void
         */
        public function group_update()
        {
            $model    = new IPTesti_Model();
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['group_id'] )) {
                $groupId = absint( $_POST['group_id'] );
                if ( $group = $model->getGroup( $groupId ) ) {
                    $this->_update_group( $group );
                } else {
                    $groupId = 0;
                }
            } else {
                $groupId = $this->_add_group();
            }
            if ( $groupId ) {
                $error = false;
            }
            if ( $error ) {
                $status  = 0;
                $groupId = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a group.', 'wp_testimony_plus' );
                } else {
                    $message = __( 'Failed to save group.', 'wp_testimony_plus' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a group.', 'wp_testimony_plus' );
                    $redirect = admin_url() . 'admin.php?page=iptesti-group&create=1';
                } else {
                    $message = __( 'Group successfully saved.', 'wp_testimony_plus' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'groupid'  => $groupId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new group
         *
         * @return int
         */
        protected function _add_group()
        {
            global $user_ID;
            
            $model = new IPTesti_Model();
            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            $slug = $model->getGroupSlug( $title );
            if ( empty( $_POST['content'] )) {
                $content = '';
            } else {
                $content = $_POST['content'];
            }
            $order = 0;
            if ( ! empty( $_POST['order'] )) {
                $order = absint( $_POST['order'] );
            }
            $data = array(
                'testi_group_created'  => date( 'c' ), 
                'testi_group_slug'     => $slug, 
                'testi_group_title'    => $title, 
                'testi_group_content'  => $content, 
                'testi_group_order'    => $order
            );
            $result = $model->insertGroup( $data );
            return $result;
        }
        
        /**
         * Update group
         *
         * @param  object $group
         * @return boolean
         */
        protected function _update_group( $group )
        {
            $result = 0;
            $data   = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $group->testi_group_title ) {
                $data['testi_group_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['content'] ) && $_POST['content'] != $group->testi_group_content ) {
                $data['testi_group_content'] = $_POST['content'];
            }
            if ( ! empty( $_POST['order'] ) && $_POST['order'] != $group->testi_group_order ) {
                $data['testi_group_order'] = absint( $_POST['order'] );
            }
            if ( ! empty( $data )) {
                $data['testi_group_id'] = $group->testi_group_id;
                $model  = new IPTesti_Model();
                $result = $model->updateGroup( $group->testi_group_id, $data );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete group
         *
         * @return void
         */
        public function group_delete()
        {
            $item  = false;
            $model = new IPTesti_Model();
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = $model->getGroup( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_testimony_plus' )
                ) );
                die();
            }
            $model  = new IPTesti_Model();
            $result = $model->deleteGroup( $item->testi_group_id );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the group', 'wp_testimony_plus' ),
                    'redirect' => admin_url() . 'admin.php?page=iptesti-group&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the group', 'wp_testimony_plus' )
                ) );
            }
            die();
        }
        
        /**
         * Update
         *
         * @return void
         */
        public function form_update()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['form_id'] )) {
                $formId = absint( $_POST['form_id'] );
                if ( $form = get_post( $formId ) ) {
                    $this->_update_form( $form );
                } else {
                    $formId = 0;
                }
            } else {
                $formId = $this->_add_form();
            }
            if ( $formId )
            {
                $error = false;
                $model = new IPTesti_Model_Form();
                $model->save_setting( $formId );
            }
            if ( $error ) {
                $status  = 0;
                $formId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a form.', 'wp_testimony_plus' );
                } else {
                    $message = __( 'Failed to save form.', 'wp_testimony_plus' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a form.', 'wp_testimony_plus' );
                    $redirect = admin_url() . 'admin.php?page=iptesti-form&create=1';
                } else {
                    $message = __( 'Form successfully saved.', 'wp_testimony_plus' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'formid'   => $formId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new form
         *
         * @return int
         */
        protected function _add_form()
        {
            global $user_ID;
            
            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => 'publish', 
                'post_type'    => 'iptesti-form', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => $_POST['description']
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update form
         *
         * @param  object $form
         * @return boolean
         */
        protected function _update_form( $form )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $form->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['description'] ) && $_POST['description'] != $form->post_content ) {
                $dataPost['post_content'] = $_POST['description'];
            }
            /* 
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $form->post_status ) {
                $dataPost['post_status'] = $status;
            }
             */
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $form->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete object
         *
         * @return void
         */
        public function form_delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_testimony_plus' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the form', 'wp_testimony_plus' ),
                    'redirect' => admin_url() . 'admin.php?page=iptesti-form&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the form', 'wp_testimony_plus' )
                ) );
            }
            die();
        }
        
        /**
         * Update
         *
         * @return void
         */
        public function style_update()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['style_id'] )) {
                $styleId = absint( $_POST['style_id'] );
                if ( $style = get_post( $styleId ) ) {
                    $this->_update_style( $style );
                } else {
                    $styleId = 0;
                }
            } else {
                $styleId = $this->_add_style();
            }
            if ( $styleId )
            {
                $error = false;
                $model = new IPTesti_Model_Style();
                $model->save_setting( $styleId );
            }
            if ( $error ) {
                $status  = 0;
                $styleId = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a style.', 'wp_testimony_plus' );
                } else {
                    $message = __( 'Failed to save style.', 'wp_testimony_plus' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a style.', 'wp_testimony_plus' );
                    $redirect = admin_url() . 'admin.php?page=iptesti-style&create=1';
                } else {
                    $message = __( 'Style successfully saved.', 'wp_testimony_plus' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'styleid'  => $styleId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new style
         *
         * @return int
         */
        protected function _add_style()
        {
            global $user_ID;
            
            if ( empty( $_POST['title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['title'] );
            }
            $dataPost = array(
                'post_status'  => 'publish', 
                'post_type'    => 'iptesti-style', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update style
         *
         * @param  object $style
         * @return boolean
         */
        protected function _update_style( $style )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['title'] ) && $_POST['title'] != $style->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $style->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete object
         *
         * @return void
         */
        public function style_delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_testimony_plus' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the style', 'wp_testimony_plus' ),
                    'redirect' => admin_url() . 'admin.php?page=iptesti-style&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the style', 'wp_testimony_plus' )
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for save setting
         *
         * @return void
         */
        public function setting()
        {
            $error = false;
            if ( isset( $_POST['slug'] )) 
            {
                $slug = apply_filters( 'pre_term_name', $_POST['slug'] );
                update_option( '__iptesti_slug', $slug );
            }
            if ( isset( $_POST['schema_shortcode'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['schema_shortcode'] );
                update_option( '__iptesti_schema_shortcode', $value );
            }
            if ( isset( $_POST['schema_widget'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['schema_widget'] );
                update_option( '__iptesti_schema_widget', $value );
            }
            if ( isset( $_POST['schema_page'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['schema_page'] );
                update_option( '__iptesti_schema_page', $value );
            }
            if ( isset( $_POST['group_as_product'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['group_as_product'] );
                update_option( '__iptesti_group_as_product', $value );
            }
            if ( isset( $_POST['product_name'] )) 
            {
                $value = apply_filters( 'single_post_title', $_POST['product_name'] );
                update_option( '__iptesti_product_name', $value );
            }
            if ( isset( $_POST['gravatar'] )) 
            {
                $value = apply_filters( 'pre_term_name', $_POST['gravatar'] );
                update_option( '__iptesti_gravatar', $value );
            }
            
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to update testimonial settings.', 'wp_testimony_plus' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully updated testimony settings.', 'wp_testimony_plus' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
    }
}                
function iptesti_set_html_content_type() 
{
    return 'text/html';
}