<?php
if ( ! class_exists( 'IPTesti_Model' )) {

    /**
     * Class for manage post setting
     */
    class IPTesti_Model
    {
        /**
         * Get Testimonies
         *
         * @param  array $args
         * @return array
         */
        public function getTestimonies( $args = array() )
        {
            global $wpdb;
            $table = $wpdb->prefix . 'iptesti_testimony';
            $query = "
                SELECT SQL_CALC_FOUND_ROWS * FROM $table WHERE 1=1
            ";
            //
            //GROUP
            if ( ! empty( $args['group'] )) {
                $groupId = absint( $args['group'] );
                $query  .= ' AND testi_group_id = ' . $groupId;
            }
            //
            //ORDER BY
            if ( ! empty( $args['orderby'] )) {
                $order = 'ASC';
                if ( ! empty( $args['order'] )) {
                    $order = $args['order'];
                }
                $query .= ' ORDER BY ' . $args['orderby'] . ' ' . $order;
            }
            //
            //LIMIT 
            if ( ! empty( $args['limit'] )) {
                $offset = 0;
                $limit  = absint( $args['limit'] );
                if ( ! empty( $args['offset'] )) {
                    $offset = absint( $args['offset'] );
                }
                $query .= ' LIMIT ' . $limit . ' OFFSET ' . $offset;
            }
            $results = $wpdb->get_results( $query );
            return $results;
        }
        
        /**
         * Get Testimony
         *
         * @param  int $id
         * @return array
         */
        public function getTestimony( $id )
        {
            global $wpdb;
            $id    = absint( $id );
            $table = $wpdb->prefix . 'iptesti_testimony';
            $sql   = "
                SELECT * FROM $table WHERE testi_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $id );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get Testimony
         *
         * @param  int $page_id
         * @return array
         */
        public function getTestimonyByPage( $page_id )
        {
            global $wpdb;
            $id    = absint( $page_id );
            $table = $wpdb->prefix . 'iptesti_testimony';
            $sql   = "
                SELECT * FROM $table WHERE testi_page = %d
            ";
            $query   = $wpdb->prepare( $sql, $page_id );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get Testimonies By Slug
         *
         * @param  string $slug
         * @return array
         */
        public function getTestimoniesBySlug( $slug )
        {
            global $wpdb;
            $slug  = sanitize_title( $slug );
            $table = $wpdb->prefix . 'iptesti_testimony';
            $query = "
                SELECT *
                FROM $table
                WHERE testi_slug LIKE '$slug%'
            ";
            $results = $wpdb->get_results( $query );
            return $results;
        }
        
        /**
         * Get testimony slug
         *
         * @param  string $slug
         * @return array
         */
        public function getTestimonySlug( $slug )
        {
            global $wpdb;
            $slug  = sanitize_title( $slug );
            $items = $this->getTestimoniesBySlug( $slug );
            if ( ! empty( $items )) {
                $count = count( $items );
                $slug .= '-' . ($count+1);
            }
            return $slug;
        }
        
        /**
         * Get Groups
         *
         * @param  array $args
         * @return array
         */
        public function getGroups( $args = array() )
        {
            global $wpdb;
            $table = $wpdb->prefix . 'iptesti_group';
            $query = "
                SELECT SQL_CALC_FOUND_ROWS * FROM $table
            ";
            //
            //ORDER BY
            if ( ! empty( $args['orderby'] )) {
                $order = 'ASC';
                if ( ! empty( $args['order'] )) {
                    $order = $args['order'];
                }
                $query .= ' ORDER BY ' . $args['orderby'] . ' ' . $order;
            }
            //
            //LIMIT 
            if ( ! empty( $args['limit'] )) {
                $offset = 0;
                $limit  = absint( $args['limit'] );
                if ( ! empty( $args['offset'] )) {
                    $offset = absint( $args['offset'] );
                }
                $query .= ' LIMIT ' . $limit . ' OFFSET ' . $offset;
            }
            $results = $wpdb->get_results( $query );
            return $results;
        }
        
        /**
         * Get Group
         *
         * @param  int $id
         * @return array
         */
        public function getGroup( $id )
        {
            global $wpdb;
            $id    = absint( $id );
            $table = $wpdb->prefix . 'iptesti_group';
            $sql   = "
                SELECT * FROM $table WHERE testi_group_id = %d
            ";
            $query   = $wpdb->prepare( $sql, $id );
            $results = $wpdb->get_row( $query );
            return $results;
        }
        
        /**
         * Get Groups By Slug
         *
         * @param  string $slug
         * @return array
         */
        public function getGroupsBySlug( $slug )
        {
            global $wpdb;
            $slug  = sanitize_title( $slug );
            $table = $wpdb->prefix . 'iptesti_group';
            $query = "
                SELECT *
                FROM $table
                WHERE testi_group_slug LIKE '$slug%'
            ";
            $results = $wpdb->get_results( $query );
            return $results;
        }
        
        /**
         * Get Group slug
         *
         * @param  string $slug
         * @return array
         */
        public function getGroupSlug( $slug )
        {
            global $wpdb;
            $slug  = sanitize_title( $slug );
            $items = $this->getGroupsBySlug( $slug );
            if ( ! empty( $items )) {
                $count = count( $items );
                $slug .= '-' . ($count+1);
            }
            return $slug;
        }
        
        /**
         * Insert Testimony
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertTestimony( $data, $format = array() )
        {
            global $wpdb;
            $table  = $wpdb->prefix . 'iptesti_testimony';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update Testimony
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateTestimony( $id, $data )
        {
            global $wpdb;
            $table  = $wpdb->prefix . 'iptesti_testimony';
            $data   = (array)$data;
            $where  = array(
                'testi_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete Testimony
         *
         * @param  int   $id
         * @return void
         */
        public function deleteTestimony( $id )
        {
            global $wpdb;
            $table  = $wpdb->prefix . 'iptesti_testimony';
            $where  = array(
                'testi_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Insert Group
         *
         * @param  array $data
         * @param  array $format
         * @return void
         */
        public function insertGroup( $data, $format = array() )
        {
            global $wpdb;
            $table  = $wpdb->prefix . 'iptesti_group';
            $data   = (array)$data;
            $result = $wpdb->insert( $table, $data, $format );
            if ( $result ) {
                return $wpdb->insert_id;
            }
            return false;
        }
        
        /**
         * Update Group
         *
         * @param  int   $id
         * @param  array $data
         * @return void
         */
        public function updateGroup( $id, $data )
        {
            global $wpdb;
            $table  = $wpdb->prefix . 'iptesti_group';
            $data   = (array)$data;
            $where  = array(
                'testi_group_id' => absint( $id )
            );
            $result = $wpdb->update( $table, $data, $where );
            return $result;
        }
        
        /**
         * Delete Group
         *
         * @param  int   $id
         * @return void
         */
        public function deleteGroup( $id )
        {
            global $wpdb;
            $table  = $wpdb->prefix . 'iptesti_group';
            $where  = array(
                'testi_group_id' => absint( $id )
            );
            $result = $wpdb->delete( $table, $where );
            return $result;
        }
        
        /**
         * Save setting testimony
         *
         * @param  int $testimonyId
         * @return void
         */
        public function save_setting( $testimonyId )
        {
            $id      = absint( $testimonyId );
            $data    = $this->_get_setting_data();
            $setting = new IPTesti_Setting( $id, '__iptesti-item-setting' );
            $result  = $setting->setSettings( $data );
            return $result;
        }
        
        /**
         * Get setting data
         *
         * @return array
         */
        protected function _get_setting_data()
        {
            $setting = array();
            $data    = array_merge( $_POST, $_GET );
             
            //
            //More title
            if ( isset( $_POST['page_more_title'] )) {
                $setting['page_more_title'] = apply_filters( 'single_post_title', $_POST['page_more_title'] );
            }
            return $setting;
        }
    }

}
?>