<?php
if ( ! class_exists( 'IPTesti_Widget_Testimony' )) {

    /**
     * Class for handling display widget
     */
    class IPTesti_Widget_Testimony extends WP_Widget
    {
        /**
         * Register widget with WordPress.
         */
        public function __construct() 
        {
            parent::__construct(
                'iptesti_testimony', // Base ID
                'Testimonials', // Name
                array( 'description' => __( 'A Widget for display testimonials', 'wp_testimony_plus' ), )
            );
        }

        /**
         * Front-end display of widget.
         *
         * @see WP_Widget::widget()
         *
         * @param array $args     Widget arguments.
         * @param array $instance Saved values from database.
         */
        public function widget( $args, $instance ) 
        {
            $factory = new IPTesti_Factory();
            $factory->testimony( $instance, $args );
        }

        /**
         * Back-end widget form.
         *
         * @see WP_Widget::form()
         *
         * @param array $instance Previously saved values from database.
         */
        public function form( $instance ) 
        {
        ?>
            <p>
                <label for="<?php echo $this->get_field_name( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
                <br>
                <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>">
            </p>
            <p>
                <label for="<?php echo $this->get_field_name( 'group' ); ?>"><?php _e( 'Group:' ); ?></label> 
                <select id="<?php echo $this->get_field_id( 'group' ); ?>" name="<?php echo $this->get_field_name( 'group' ); ?>">
                    <?php
                    $group_id = absint( $instance['group'] );
                    $model    = new IPTesti_Model();
                    $groups   = $model->getGroups();
                    foreach( $groups as $group ) 
                    {
                        $selected = '';
                        if ( $group_id == $group->testi_group_id ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $group->testi_group_id .  '">' . $group->testi_group_title . '</option>';
                    }
                    ?>
                </select>
            </p>
            <p>
                <?php
                $orderby = $instance['orderby'];
                $order   = $instance['order'];
                ?>
                <label for="<?php echo $this->get_field_name( 'orderby' ); ?>"><?php _e( 'Order By:' ); ?></label> 
                <br>
                <select id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>">
                    <?php
                    $fields = array(
                        'order'   => __( 'Order Attribute', 'wp_testimony_plus' ),
                        'name'    => __( 'Author Name', 'wp_testimony_plus' ),
                        'created' => __( 'Date Created', 'wp_testimony_plus' ),
                        'rating'  => __( 'Rating', 'wp_testimony_plus' ),
                    );
                    foreach( $fields as $key => $label ) 
                    {
                        $selected = '';
                        if ( $orderby == $key ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $key .  '">' . $label . '</option>';
                    }
                    ?>
                </select>
                <select id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>">
                    <?php
                    $fields = array(
                        'asc'     => __( 'Ascending', 'wp_testimony_plus' ),
                        'desc'    => __( 'Descending', 'wp_testimony_plus' )
                    );
                    foreach( $fields as $key => $label ) 
                    {
                        $selected = '';
                        if ( $order == $key ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $key .  '">' . $label . '</option>';
                    }
                    ?>
                </select>
            </p>
            <p>
                <label for="<?php echo $this->get_field_name( 'limit' ); ?>"><?php _e( 'Limit:' ); ?></label> 
                <input type="text" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" value="<?php echo $instance['limit']; ?>">
            </p>
            <p>
                <label for="<?php echo $this->get_field_name( 'style' ); ?>"><?php _e( 'Style:' ); ?></label> 
                <select id="<?php echo $this->get_field_id( 'style' ); ?>" name="<?php echo $this->get_field_name( 'style' ); ?>">
                    <?php
                    $style_id = absint( $instance['style'] );
                    $args = array(
                        'orderby'        => 'post_title',
                        'order'          => 'DESC', 
                        'post_type'      => 'iptesti-style',
                        'post_status'    => array('publish'),
                        'posts_per_page' => -1,
                        'paged'          => 1
                    );
                    $query  = new WP_Query;
                    $styles = $query->query( $args );
                    foreach( $styles as $style ) 
                    {
                        $selected = '';
                        if ( $style_id == $style->ID ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $style->ID .  '">' . $style->post_title . '</option>';
                    }
                    ?>
                </select>
            </p>
            <p>
                <label for="<?php echo $this->get_field_name( 'product' ); ?>"><?php _e( 'Product Being Reviewed:' ); ?></label> 
                <br>
                <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'product' ); ?>" name="<?php echo $this->get_field_name( 'product' ); ?>" value="<?php echo $instance['product']; ?>">
            </p>
            <?php 
        }

        /**
         * Sanitize widget form values as they are saved.
         *
         * @see WP_Widget::update()
         *
         * @param array $new_instance Values just sent to be saved.
         * @param array $old_instance Previously saved values from database.
         *
         * @return array Updated safe values to be saved.
         */
        public function update( $new_instance, $old_instance ) 
        {
            $instance = array();
            if ( ! empty( $new_instance['title'] ) ) {
                $instance['title'] = apply_filters( 'single_post_title', $new_instance['title'] ); 
            }
            if ( ! empty( $new_instance['group'] ) ) {
                $instance['group'] = absint( $new_instance['group'] ); 
            }
            if ( ! empty( $new_instance['style'] ) ) {
                $instance['style'] = absint( $new_instance['style'] ); 
            }
            if ( ! empty( $new_instance['order'] ) ) {
                $instance['order'] = apply_filters( 'pre_term_name', $new_instance['order'] );
            }
            if ( ! empty( $new_instance['orderby'] ) ) {
                $instance['orderby'] = apply_filters( 'pre_term_name', $new_instance['orderby'] );
            }
            if ( ! empty( $new_instance['product'] ) ) {
                $instance['product'] = apply_filters( 'single_post_title', $new_instance['product'] );
            }
            if ( ! empty( $new_instance['limit'] ) ) {
                $instance['limit'] = absint( $new_instance['limit'] ); 
            }
            return $instance;
        }
    }

}
?>